export ENV_VAR_FILE=$1; 		#File path having environment variables

export TF_TABLE=$2; 			#File path having Pfam domain ids
export LOG_DIR=$3; 			#Directory to save executable files and log messages
export NAME_PROG=$4; 			#Name for executable files
export QTD_FILE=$5; 			#Amount of commands saved per executable file. It is usefull for MPI, if you are using just one machine set it with exact number of domains in the Pfam domain list.

export RESULT_FILE=$6;			#CLADE result file.
export RESULT_FILE_BEST=$7;		#It is a output file where will be saved the best hits of CLADE result file.
export LIST_FILE=$8;			#List having selected species.
export TAXON_MODEL_FILE=$9;		#File having the taxon hierarchy for each species into a given Pfam domain, to understand the taxon codes see http://www.uniprot.org/taxonomy
export SEQUENCE_FILE=${10};		#Database in FASTA format scanned by CLADE library in the previous step
export ATTRIBUTE_FILE=${11};		#Output file
export EV_CUT_OFF=${12};		#E-value cut-off
export DOMAIN_AVG_FILE=${13};		#Input file having domain average size
export TAXON_DIR=${14};			#TAXON directory having taxon hierarchy for each species in SEQUENCE_FILE


source $ENV_VAR_FILE;

export VERBOSE=false;
export TAXON_LEVEL=3;
export DOM_COV=0.01;
export FILTRE_EV=1;

export IS_TEST=true;
export FILTRE=false;

export VERBOSE=false;


perl $PERL_LIB/run/runTestSetPFAMFamily.pl \
-trans_factor_table $TF_TABLE \
-nameRun ${NAME_PROG}_runFamily \
-logDir $LOG_DIR \
-kindRun 1 \
-qtdFile $QTD_FILE \
-prePost \( \
echo \"LOG::START::FAMILY_FACTOR\", \
date, \
TOP echo \$HOSTNAME, \
TOP export PERL_LIB=$PERL_LIB, \
TOP export BASE_DIR=$BASE_DIR, \
TOP export TMP_DIR=$TMP/NUM_FILE/, \
TOP mkdir -p \$TMP_DIR, \
TOP export SEQUENCE_FILE_TMP=\$TMP_DIR/test.taxon, \
TOP export MAPPING_FILE_TMP=\$TMP_DIR/test.map, \
TOP cp $SEQUENCE_FILE \$SEQUENCE_FILE_TMP, \
TOP grep \"\>\" \$SEQUENCE_FILE_TMP \>  \$MAPPING_FILE_TMP, \
TOP sed \'s/\>//g\'  \$MAPPING_FILE_TMP \>  \$MAPPING_FILE_TMP.aux, \
TOP mv  \$MAPPING_FILE_TMP.aux \$MAPPING_FILE_TMP, \
export RESULT_FILE_TMP=\$TMP_DIR/FAMILY_FACTOR_result_resume.txt, \
export RESULT_FILE_BEST_TMP=\$TMP_DIR/FAMILY_FACTOR_result_resume.txt.best, \
export RESULT_FILE_BEST_AVG_TMP=\$TMP_DIR/FAMILY_FACTOR_result_resume.txt.best.avg, \
export RESULT_FILE_DOMAIN=\$TMP_DIR/FAMILY_FACTOR.domains, \
export LIST_FILE_TMP=\$TMP_DIR/FAMILY_FACTOR.list, \
export TAXON_MODEL_FILE_TMP=\$TMP_DIR/FAMILY_FACTOR_model.taxon, \
cp $LIST_FILE \$LIST_FILE_TMP, \
cp $RESULT_FILE \$RESULT_FILE_TMP, \
cp $TAXON_MODEL_FILE \$TAXON_MODEL_FILE_TMP \
\) \
-scriptParameters \( \
END_LINE,\
perl $BASE_DIR/scripts/ensemble/cut_domain_by_size.pl, \
-resultFile \$RESULT_FILE_TMP, \
-outputFile \$RESULT_FILE_BEST_TMP, \
-evalue_CUTOFF $EV_CUT_OFF, \
-overlap true, \
-verbose $VERBOSE, \
END_LINE,\
if [ -s \$RESULT_FILE_BEST_TMP ], \
END_LINE,\
then, \
END_LINE, \
eval QTD_MODELS=\`grep -c \"\" \$LIST_FILE_TMP\`, \
END_LINE, \
let QTD_MODELS=QTD_MODELS\+1, \
END_LINE, \
perl $BASE_DIR/scripts/ensemble/domain_average.pl, \
-resultFile \$RESULT_FILE_TMP, \
-resultFileBest \$RESULT_FILE_BEST_TMP, \
-outputFile \$RESULT_FILE_BEST_AVG_TMP, \
-verbose $VERBOSE, \
END_LINE, \
cp \$RESULT_FILE_BEST_TMP $RESULT_FILE_BEST, \
END_LINE,\
cp \$RESULT_FILE_BEST_AVG_TMP $RESULT_FILE_BEST.avg, \
END_LINE,\
perl \$BASE_DIR/scripts/ensemble/createAtributtesVector.pl, \
-resultFileBest \$RESULT_FILE_BEST_AVG_TMP, \
-resultFile \$RESULT_FILE_TMP, \
-taxonModelFile \$TAXON_MODEL_FILE_TMP, \
-totalModels \$QTD_MODELS, \
-taxonTestFile \$TAXON_TEST_FILE_TMP, \
-test $IS_TEST, \
-outputFile \$TMP_DIR/FAMILY_FACTOR_attributes.txt, \
-verbose $VERBOSE, \
-taxonDir $TAXON_DIR, \
-tmpDir \$TMP_DIR, \
-filtre $FILTRE, \
-level $TAXON_LEVEL, \
-filtreEv $FILTRE_EV, \
-domainAvgFile $DOMAIN_AVG_FILE, \
-mappingTaxon \$MAPPING_FILE_TMP, \
-PFAM_ACC FAMILY_FACTOR, \
END_LINE, \
if [ -s \$TMP_DIR/FAMILY_FACTOR_attributes.txt ], \
END_LINE,\
then, \
END_LINE,\
export DIR=\$\(dirname ${ATTRIBUTE_FILE}\), \
END_LINE,\
mkdir -p \$DIR, \
END_LINE,\
cp \$TMP_DIR/FAMILY_FACTOR_attributes.txt $ATTRIBUTE_FILE, \
END_LINE,\
echo \"File created \: $ATTRIBUTE_FILE\", \
END_LINE,\
else, \
END_LINE,\
echo \"ERROR File NOT created \: $ATTRIBUTE_FILE\", \
END_LINE,\
fi, \
END_LINE,\
else, \
END_LINE, \
echo \"ERROR File NOT created \: $RESULT_FILE_BEST by using evalue $EV_CUT_OFF \", \
END_LINE, \
fi, \
END_LINE \
\)  \
-posPost \( \
echo \" LOG::END \", \
BOTTOM rm -rf \$TMP_DIR, \
date \
\) \
-commandParameters  \( bash \)
